<?php
/**
 * Header: $Id: cookie.php 5165 2012-06-07 08:00:19Z calicant $
 *
 * @version $Revision: 1.2 $
 * @package DataHandler
 * @author  $Author: antonio $
 */


class Cookie extends DataHandler
{
    /**
     * Cookie name
     *
     * @var	string
     * @access	private
     */
	var $_cookie_name;

	/**
     * Cookie expire
     *
     * @var	unix time
     * @access	private
     */
	var $_cookie_expire = 0;

	/**
     * Cookie path
     *
     * @var	string
     * @access	private
     */
	var $_cookie_path = '';

    /**
     * Cookie domain
     *
     * @var	string
     * @access	private
     */
	var $_cookie_domain = '';

	/**
     * Cookie secure (to use through https)
     *
     * @var	int
     * @access	private
     */
	var $_cookie_secure = 0;

    /**
     * List of names ov vars currently registered
     *
     * @var	array
     * @access	private
     */
    var $_registered_vars_list;

    /**
     * Constructs a new cookie object.
	 * The advantage is that item in cookie are already
	 * avaible, you have not to reload the page
	 * Call it before every output.
     *
     * @param	string $session_name  The session name
     *
     * @access	public
     */

    function Cookie ($conf = array())
	{
		$this->_cookie_name = $conf[cookie_name];
		$this->_cookie_expire = $conf[cookie_expire];
		$this->_cookie_path = $conf[cookie_path];
		$this->_cookie_domain = $conf[cookie_domain];
		$this->_cookie_secure = $conf[cookie_secure];
		$this->_registered_vars_list = array();
		$this->_init_cookie();
    }

    /**
     * Add new item item to the cookie.
	 * Call it before every output.
     *
     * @param	string	$itemname	itemname to register
     * @param	mixed	$item		item to add
     *
     * @access	public
     */
    function add ($itemname, $item)
	{
	    $this->_registered_vars_list[$itemname] = $item;
        $val = $this->_serialize_cookie($this->_registered_vars_list);
        setcookie($this->_cookie_name, $val, $this->_cookie_expire, $this->_cookie_path, $this->_cookie_domain, $this->_cookie_secure);
    }

    /**
     * Remove an item from the cookie
	 * Call it before every output.
     *
     * @param	string	$itemname   item name
     *
     * @access	public
     */
    function remove ($itemname)
	{
		unset($this->_registered_vars_list[$itemname]);
		$val = $this->_serialize_cookie($this->_registered_vars_list);
		setcookie($this->_cookie_name, $val, $this->_cookie_expire, $this->_cookie_path, $this->_cookie_domain, $this->_cookie_secure);
    }

    /**
     * Get the value of item registered in the cookie
     *
     * @param	string	$itemname	item name
     *
     * @access	public
     */
    function getvalue ($itemname)
	{
	    return $this->_registered_vars_list[$itemname];
    }

    /**
     * Test if an item is registered in the cookie
     *
     * @param	string	$itemname	item name
     *
     * @access	public
     */
    function exists ($itemname)
	{
        return isset($this->_registered_vars_list[$itemname]);
    }

    /**
     * Destroy a session object
     *
     *
     */
    function close ()
	{
	    $this->_unregisterAll();
        setcookie($this->_cookie_name, '', $this->_cookie_expire, $this->_cookie_path, $this->_cookie_domain, $this->_cookie_secure);
    }

    /**
     * Unregister all variables currently registered
     *
     *
     * @access private     */

    function _unregisterAll()
	{
		reset($this->_registered_vars_list);
		while (list($k, $v) = each($this->_registered_vars_list))
			if ($v)
			unset($_SESSION[$k]);
    }

    /**
     * Initialize session before to seting/getting vars
     *
     *
     * @param	string	$session_name	name of session
     *
     * @access private
     */
    function _init_cookie ()
	{
	    $val = $this->_serialize_cookie($this->_registered_vars_list);
        setcookie($this->_cookie_name, $val, $this->_cookie_expire, $this->_cookie_path, $this->_cookie_domain, $this->_cookie_secure);
    }

	function _serialize_cookie($vars)
	{
        return serialize($vars);
	}

	function _unserialize_cookie()
	{
        return unserialize($this->_registered_vars_list);
	}


} // class


?>
